@@ -160,7 +160,7 @@ PCx(LP, Solution, Inputs)
    Corrector = NewIterate(NumRows, NumCols, NumBounds);
    Corrector->BoundIndex = iupbound;
    
-   min_phi = NewDouble(Inputs->IterationLimit, "min_phi");
+   min_phi = NewDouble(Inputs->IterationLimit+1, "min_phi");
    
    /* Compute norms for convergence tests */
    
